library(ggplot2)

#source('C:/Users/Yair/Dropbox/University/Eyal - Research/Quantile Regression/code/complete_simulation.R')
#source('C:/Users/Yair/Dropbox/University/Eyal - Research/Quantile Regression/code/sampling_schemes.R')
#source('C:/Users/Yair/Dropbox/University/Eyal - Research/Quantile Regression/code/run_simulations.R')

#img_folder <-'C:/Users/Eyal/Dropbox/University/Research/Quantile Regression/images/'
#data_folder <- 'C:/Users/Eyal/Dropbox/University/Research/Quantile Regression/data/'
#file_name <- 'binom'

get_comparison_datset <- function(steps, alpha, function_to_use, function_name)
{
  rm_errors <- c()
  erm_errors <- c()
  regular_regression_errors <- c()
  adaptive_regression_errors <- c()
  rm_regression_errors <- c()
  rm_efficient_regression_errors <- c()
  
  rm_error <- function_to_use(steps, robbins_monro_interval, alpha = alpha)
  erm_error <- function_to_use(steps, efficient_robbins_monro, alpha = alpha)
  regular_regression_error <- function_to_use(steps, regular_regression, alpha = alpha)
  adaptive_regression_error <- function_to_use(steps, adaptive_regression, alpha = alpha)
      
  rm_errors <- c(rm_errors, rm_error)
  erm_errors <- c(erm_errors, erm_error)
  regular_regression_errors <- c(regular_regression_errors, regular_regression_error)
  adaptive_regression_errors <- c(adaptive_regression_errors, adaptive_regression_error)
      
  d1 <- data.frame(error=rm_errors, steps=steps, Algorithm='Robbins-Monro', sim_name = function_name, alpha=alpha)
  d2 <- data.frame(error=erm_errors, steps=steps, Algorithm='Binary Robbins-Monro', sim_name = function_name, alpha=alpha)
  d3 <- data.frame(error=regular_regression_errors, steps=steps, Algorithm='Quantile Regression', sim_name = function_name, alpha=alpha)
  d4 <- data.frame(error=adaptive_regression_errors, steps=steps, Algorithm='Adaptive Quantile Regression', sim_name = function_name, alpha=alpha)
  data <- rbind(d1, d2, d3, d4)
      
  return(data)
}

## concat the results from all combinations of alpha, steps and function

steps_list <- seq(40, 400, length.out = 10)
alpha_list <- c(0.2, 0.1, 0.05, 0.01)

results <- vector("list", length = length(alpha_list) * length(steps_list) * 3)
i <- 1
for(alpha in alpha_list)
{
  for(steps in steps_list)
  {
    results[[i]] <- get_comparison_datset(steps, alpha, run_normal_simulation, "normal_mean")
    i <- i + 1
    results[[i]] <- get_comparison_datset(steps, alpha, run_logistic_simulation, "logistic")
    i <- i + 1
    results[[i]] <- get_comparison_datset(steps, alpha, run_normal_simulation, "normal_sd")
    i <- i + 1
  }
}

results_dataset <- do.call(rbind, results)

p <- results_dataset %>% filter(alpha == 0.01) %>% ggplot(aes(x=steps, y=error, colour=Algorithm, linetype=Algorithm)) + 
  geom_line() + facet_grid(sim_name ~ alpha, scales = "free_y") + 
  scale_color_manual(values=c("green", "orange", "red", "blue")) +
  scale_linetype_manual(values = c('dashed', 'dotted', 'longdash', 'solid')) +
  ylab("Square Root MSE") + xlab("Iterations") + ylim(c(0,1))

print(p)

write_csv(results_dataset, path = "~/Dropbox (Cambridge University)/Projects/quantreg/data/different_alpha_results.csv")
save(data, file = paste0(data_folder, file_name, '.RData'))
ggsave(paste0(img_folder, file_name, '.png'))

for (i in 1:10)
{
  algo <- 'Hot-started Robbins monro'
  steps <- data[data$Algorithm==algo,2][i]
  error <- data[data$Algorithm==algo,1][i]
  cat('(',steps , ',' ,error,')', '\n')
}

data <- data.frame(theta=NULL, hat_theta=NULL)
for(theta in thetas)
{
  sample <- rnorm(10, mean=theta, sd=1)
  data <- rbind(data, data.frame(theta=theta, hat_theta=sample))
}

for(i in 1:nrow(data))
{
  cat('(',data[i,1] , ',' ,data[i,2],')', '\n')

}
