#source('C:/Users/Yair/Dropbox/University/Eyal - Research/Quantile Regression/code/complete_simulation.R')
#source('C:/Users/Yair/Dropbox/University/Eyal - Research/Quantile Regression/code/sampling_schemes.R')

run_normal_simulation <- function(steps, method, alpha = 0.05)
{
  correct_endpoint <- qnorm(1-alpha)
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=0,
    range_l=-50,
    range_u=60,
    start=correct_endpoint,
    correct_endpoint=correct_endpoint,
    alpha = alpha,
    steps=steps,
    sampling_func=sample_normal,
    reps=500)

  return(error)
}

run_logistic_simulation <- function(steps, method, alpha = 0.05)
{
  correct_endpoint <- qlogis(1 - alpha)
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=0,
    range_l=-100,
    range_u=110,
    start=correct_endpoint,
    correct_endpoint=correct_endpoint,
    alpha=alpha,
    steps=steps,
    sampling_func=sample_logistic,
    reps=500)

  return(error)
}


run_normal_variance_simulation <- function(steps, method, alpha = 0.05)
{
  dfs <- 9 # SD calcualted from 10 samples. SD estimate is based on n-1. 
  estimate <- 0.1
  correct_endpoint <- sqrt((dfs*estimate^2)/qchisq(alpha, df = dfs)) # Based on the distribution of sample variance.
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=estimate,
    range_l=0.1,
    range_u=0.5,
    start = correct_endpoint,
    correct_endpoint=correct_endpoint,
    alpha=alpha,
    steps=steps,
    sampling_func=sample_norm_variance,
    reps=500)

  return(error)
}

run_gamma_simulation_5 <- function(steps, method)
{
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=1,
    range_l=1,
    range_u=5,
    start = 2.537881,
    correct_endpoint=2.537881,
    alpha=0.05,
    steps=steps,
    sampling_func=sample_gamma_5,
    reps=300)

  return(error)
}

run_gamma_simulation_10 <- function(steps, method)
{
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=1,
    range_l=1,
    range_u=5,
    start = 1.845427,
    correct_endpoint=1.845427,
    alpha=0.05,
    steps=steps,
    sampling_func=sample_gamma_10,
    reps=300)

  return(error)
}

run_binom_simulation <- function(steps, method)
{
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=0.5,
    range_l=0,
    range_u=1,
    start = 1,
    correct_endpoint=0.6237541,
    alpha=0.05,
    steps=steps,
    sampling_func=sample_binom,
    reps=300)

  return(error)
}


run_normal_quad_simulation <- function(steps, method)
{
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=1,
    range_l=1.5,
    range_u=3,
    start = 2.2,
    correct_endpoint=2.274597,
    alpha=.005,
    steps=steps,
    sampling_func=sample_norm_quad,
    reps=100)

  return(error)
}


run_normal_decreasing <- function(steps, method)
{
  error <- calculate_mse_from_simulation(
    method_func=method,
    estimate=1,
    range_l=1.5,
    range_u=2.5,
    start = 2,
    correct_endpoint=1.990161,
    alpha=0.05,
    steps=steps,
    sampling_func=sample_normal_decreasing,
    reps=100)

  return(error)
}

